@@ -208,7 +208,7 @@ psutil_disk_partitions(PyObject *self, PyObject *args) {
 
     while ((entry = getmntent(file))) {
         if (entry == NULL) {
-            PyErr_Format(PyExc_RuntimeError, "getmntent() failed");
+            PyErr_Format(PyExc_RuntimeError, "getmntent() syscall failed");
             goto error;
         }
         py_tuple = Py_BuildValue("(ssss)",
@@ -402,11 +402,15 @@ psutil_proc_cpu_affinity_set(PyObject *self, PyObject *args) {
 #else
         long value = PyInt_AsLong(item);
 #endif
-        if (value == -1 && PyErr_Occurred())
+        if ((value == -1) || PyErr_Occurred()) {
+            if (!PyErr_Occurred())
+                PyErr_SetString(PyExc_ValueError, "invalid CPU value");
             goto error;
+        }
         CPU_SET(value, &cpu_set);
     }
 
+
     len = sizeof(cpu_set);
     if (sched_setaffinity(pid, len, &cpu_set)) {
         PyErr_SetFromErrno(PyExc_OSError);
@@ -476,16 +480,14 @@ error:
  * http://www.i-scream.org/libstatgrab/
  */
 static PyObject*
-psutil_net_if_stats(PyObject* self, PyObject* args) {
+psutil_net_if_duplex_speed(PyObject* self, PyObject* args) {
     char *nic_name;
     int sock = 0;
     int ret;
     int duplex;
     int speed;
-    int mtu;
     struct ifreq ifr;
     struct ethtool_cmd ethcmd;
-    PyObject *py_is_up = NULL;
     PyObject *py_retlist = NULL;
 
     if (! PyArg_ParseTuple(args, "s", &nic_name))
@@ -496,22 +498,6 @@ psutil_net_if_stats(PyObject* self, PyObject* args) {
         goto error;
     strncpy(ifr.ifr_name, nic_name, sizeof(ifr.ifr_name));
 
-    // is up?
-    ret = ioctl(sock, SIOCGIFFLAGS, &ifr);
-    if (ret == -1)
-        goto error;
-    if ((ifr.ifr_flags & IFF_UP) != 0)
-        py_is_up = Py_True;
-    else
-        py_is_up = Py_False;
-    Py_INCREF(py_is_up);
-
-    // MTU
-    ret = ioctl(sock, SIOCGIFMTU, &ifr);
-    if (ret == -1)
-        goto error;
-    mtu = ifr.ifr_mtu;
-
     // duplex and speed
     memset(&ethcmd, 0, sizeof ethcmd);
     ethcmd.cmd = ETHTOOL_GSET;
@@ -537,15 +523,13 @@ psutil_net_if_stats(PyObject* self, PyObject* args) {
     }
 
     close(sock);
-    py_retlist = Py_BuildValue("[Oiii]", py_is_up, duplex, speed, mtu);
+    py_retlist = Py_BuildValue("[ii]", duplex, speed);
     if (!py_retlist)
         goto error;
-    Py_DECREF(py_is_up);
     return py_retlist;
 
 error:
-    Py_XDECREF(py_is_up);
-    if (sock != 0)
+    if (sock != -1)
         close(sock);
     PyErr_SetFromErrno(PyExc_OSError);
     return NULL;
@@ -578,8 +562,8 @@ PsutilMethods[] = {
      "device, mount point and filesystem type"},
     {"users", psutil_users, METH_VARARGS,
      "Return currently connected users as a list of tuples"},
-    {"net_if_stats", psutil_net_if_stats, METH_VARARGS,
-     "Return NIC stats (isup, duplex, speed, mtu)"},
+    {"net_if_duplex_speed", psutil_net_if_duplex_speed, METH_VARARGS,
+     "Return duplex and speed info about a NIC"},
 
     // --- linux specific
 
